<?php
/**
 * Copyright (C) 2017-2019 Petr Hucik <petr@getdatakick.com>
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@getdatakick.com so we can send you a copy immediately.
 *
 * @author    Petr Hucik <petr@getdatakick.com>
 * @copyright 2017-2019 Petr Hucik
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 */

namespace Chex;

use Cart;
use CMS;
use Configuration;
use Context;
use Db;
use PrestaShopDatabaseException;
use PrestaShopException;
use Tools;
use Translate;

class DmHeurekaAdapter implements EntryFieldsIntegration
{
    /**
     * @var bool
     */
    private $enabled;

    /**
     * DmHeurekaAdapter constructor.
     * @throws PrestaShopException
     */
    public function __construct()
    {
        $this->enabled = (
            Configuration::get('DM_HEUREKA_OVERENO') == 1 &&
            Configuration::get('DM_HEUREKA_OVERENO_SOUHLAS') == 1
        );
    }

    /**
     * @return array
     * @throws PrestaShopDatabaseException
     * @throws PrestaShopException
     */
    function getEntryFields()
    {
        $cmsId = Configuration::get('DM_HEUREKA_ID_CMS');
        if ($cmsId != 'N') {
            $context = Context::getContext();
            $cms = new CMS((int)$cmsId, $context->language->id);
            $cmsLink = Context::getContext()->link->getCMSLink($cms->id, $cms->link_rewrite);
            $label = Translate::ppTags(
                sprintf($this->l('Do not send me review request email. [1]%s[/1]'), $cms->meta_title),
                ['<a href="' . $cmsLink . '" target="tos">']
            );
        } else {
            $label = $this->l('Do not send me review request email');
        }

        return [
            [
                'id' => 'confirm.revokeHeurekaConsent',
                'label' => $label,
                'required' => false,
                'type' => 'checkbox',
                'hidden' => !$this->enabled,
            ]
        ];
    }

    /**
     * @return string
     */
    function getId()
    {
        return 'dm_heureka';
    }

    /**
     * @param string $id
     * @param mixed $value
     * @param Cart $object
     *
     * @return bool|void
     * @throws PrestaShopException
     */
    function processEntryField($id, $value, $object)
    {
        if ($id === 'confirm.revokeHeurekaConsent') {
            $revoke = !!$value;
            $value = $revoke ? 0 : 1;
            $cartId = (int)$object->id;
            $ip = inet_pton(Tools::getRemoteAddr());

            return Db::getInstance()->execute("
                INSERT INTO " . _DB_PREFIX_ . "dm_heureka_consent(id_cart, dm_heureka_consent, dm_heureka_consent_ip, dm_heureka_send) 
                VALUES ($cartId, $value, '$ip', 0)
                ON DUPLICATE KEY UPDATE dm_heureka_consent=VALUES(dm_heureka_consent), dm_heureka_consent_ip=VALUES(dm_heureka_consent_ip)
            ");
        }
    }

    /**
     * @param string $field
     * @param string $search
     * @return mixed
     * @throws PrestaShopException
     */
    function getSelectOptions($field, $search)
    {
        throw new PrestaShopException('Not implemented');
    }

    /**
     * @param string $str
     * @return string
     */
    public function l($str)
    {
        return Translate::getModuleTranslation('chex', $str, 'carrier.dm_heureka');
    }

}
