<?php
/**
 * Copyright (C) 2017-2019 Petr Hucik <petr@getdatakick.com>
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@getdatakick.com so we can send you a copy immediately.
 *
 * @author    Petr Hucik <petr@getdatakick.com>
 * @copyright 2017-2019 Petr Hucik
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 */

namespace Chex;

use Configuration;
use PrestaShopDatabaseException;
use PrestaShopException;
use Address;
use Translate;
use VatNumber;

class VatNumberAdapter implements EntryFieldsIntegration
{
    /**
     * @var bool
     */
    private $enabled;

    /**
     * DmHeurekaAdapter constructor.
     * @throws PrestaShopException
     */
    public function __construct()
    {
        $this->enabled = (
            defined('VatNumber::VAT_EXEMPTION_FLAG') &&
            !!Configuration::get('VATNUMBER_MANAGEMENT') &&
            !!Configuration::get('VATNUMBER_MANUAL')
        );
    }

    /**
     * @return array
     */
    function getEntryFields()
    {
        return [
            [
                'id' => 'address.vatExemption',
                'label' => $this->l('I qualify for VAT Relief'),
                'required' => false,
                'hidden' => !$this->enabled,
                'type' => 'checkbox',
            ]
        ];
    }

    /**
     * @return string
     */
    function getId()
    {
        return 'vatnumber';
    }

    /**
     * @param string $id
     * @param boolean $exemption
     * @param Address $address
     *
     * @return void
     * @throws PrestaShopException
     * @throws PrestaShopDatabaseException
     */
    function processEntryField($id, $exemption, $address)
    {
        if ($id === 'address.vatExemption') {
            if (!! $exemption && (! $address->vat_number)) {
                $address->vat_number = VatNumber::VAT_EXEMPTION_FLAG;
                $address->update();
            }
        }
    }

    /**
     * @param string $field
     * @param string $search
     * @return mixed
     * @throws PrestaShopException
     */
    function getSelectOptions($field, $search)
    {
        throw new PrestaShopException('Not implemented');
    }

    /**
     * @param string $str
     * @return string
     */
    public function l($str)
    {
        return Translate::getModuleTranslation('chex', $str, 'carrier.vatNumber');
    }

}
