<?php
/**
 * Copyright (C) 2017-2019 Petr Hucik <petr@getdatakick.com>
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@getdatakick.com so we can send you a copy immediately.
 *
 * @author    Petr Hucik <petr@getdatakick.com>
 * @copyright 2017-2019 Petr Hucik
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 */

namespace Chex;

use Hook;
use Module;
use PrestaShopException;

class Integrations
{
    /** @var EntryFieldsIntegration[] */
    private $entryFields;

    /** @var ShippingIntegration[] */
    private $shipping;

    /**
     * @return string[]
     */
    private static function getShippingAdapters()
    {
        return [
            'shaim_zasilkovna' => '\Chex\ShaimZasilkovnaAdapter',
        ];
    }

    /**
     * @return string[]
     */
    private static function getEntryFieldsAdapters()
    {
        return [
            'dm_heureka' => '\Chex\DmHeurekaAdapter',
            'vatnumber' => '\Chex\VatNumberAdapter',
        ];
    }

    /**
     * @return ShippingIntegration[]
     * @throws PrestaShopException
     */
    public function getShippingIntegrations()
    {
        if (is_null($this->shipping)) {
            $this->shipping = [];
            foreach (static::getShippingAdapters() as $module => $class) {
                if (Module::isInstalled($module) && Module::isEnabled($module)) {
                    $file = __DIR__ . '/shipping/' . $module . '.php';
                    if (is_file($file)) {
                        require_once($file);
                        $this->shipping[$module] = new $class();
                    }
                }
            }

            $moduleIntegrations = Hook::exec('actionGetChexShipping', [], null, true);
            if ($moduleIntegrations) {
                foreach ($moduleIntegrations as $moduleKey => $integration) {
                    $this->shipping[$moduleKey] = $integration;
                }
            }
        }
        return $this->shipping;
    }

    /**
     * @return EntryFieldsIntegration[]
     * @throws PrestaShopException
     */
    public function getEntryFieldsIntegrations()
    {
        if (is_null($this->entryFields)) {
            $this->entryFields = [];
            foreach (static::getEntryFieldsAdapters() as $module => $class) {
                if (Module::isInstalled($module) && Module::isEnabled($module)) {
                    $file = __DIR__ . '/entry-fields/' . $module . '.php';
                    if (is_file($file)) {
                        require_once($file);
                        $this->entryFields[$module] = new $class();
                    }
                }
            }

            $moduleIntegrations = Hook::exec('actionGetChexEntryFields', [], null, true);
            if ($moduleIntegrations) {
                foreach ($moduleIntegrations as $moduleKey => $integration) {
                    $this->entryFields[$moduleKey] = $integration;
                }
            }
        }
        return $this->entryFields;
    }

    /**
     * @param string $integration
     * @return EntryFieldsIntegration|null
     * @throws PrestaShopException
     */
    public function getEntryFieldsIntegration($integration)
    {
        $integrations = $this->getEntryFieldsIntegrations();
        return $integrations[$integration] ?? null;
    }

}
